@@ -3,11 +3,16 @@
 # WARNING ABOUT GENERATED CODE
 #
 # This file is generated. See the contributing guide for more information:
-# https://github.com/aws/aws-sdk-ruby/blob/master/CONTRIBUTING.md
+# https://github.com/aws/aws-sdk-ruby/blob/version-3/CONTRIBUTING.md
 #
 # WARNING ABOUT GENERATED CODE
 
 
+unless Module.const_defined?(:Aws)
+  require 'aws-sdk-core'
+  require 'aws-sigv4'
+end
+
 require_relative 'aws-sdk-sts/types'
 require_relative 'aws-sdk-sts/client_api'
 require_relative 'aws-sdk-sts/client'
@@ -42,9 +47,9 @@ require_relative 'aws-sdk-sts/customizations'
 #
 # See {Errors} for more information.
 #
-# @service
+# @!group service
 module Aws::STS
 
-  GEM_VERSION = '3.104.3'
+  GEM_VERSION = '3.132.0'
 
 end
